"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = require("react");

var _propTypes = _interopRequireDefault(require("prop-types"));

var _draftJs = require("draft-js");

var _highlightToCompositeDecorator = _interopRequireDefault(require("./highlightToCompositeDecorator.js"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr && (typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]); if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

var HighlightWithinTextarea = /*#__PURE__*/(0, _react.forwardRef)(function (props, ref) {
  var placeholder = props.placeholder,
      highlight = props.highlight,
      onChange = props.onChange,
      value = props.value;

  var _useState = (0, _react.useState)({
    prev: {
      value: null,
      editorState: null
    },
    next: {
      value: null,
      editorState: null
    }
  }),
      _useState2 = _slicedToArray(_useState, 2),
      onChangeState = _useState2[0],
      setOnChangeState = _useState2[1];

  var editorState;

  if (value === onChangeState.next.value) {
    editorState = onChangeState.next.editorState;
  } else if (value === onChangeState.prev.value) {
    editorState = onChangeState.prev.editorState;
  } else {
    var contentState = _draftJs.ContentState.createFromText(value);

    editorState = _draftJs.EditorState.createWithContent(contentState);
  }

  var decorator = (0, _react.useMemo)(function () {
    return (0, _highlightToCompositeDecorator.default)(highlight);
  }, [highlight]);

  if (decorator !== editorState.decorator) {
    editorState = _draftJs.EditorState.set(editorState, {
      decorator: decorator
    });
  }

  var onDraftChange = function onDraftChange(editorState) {
    var value = editorState.getCurrentContent().getPlainText();
    setOnChangeState({
      prev: onChangeState.next,
      next: {
        value: value,
        editorState: editorState
      }
    });
    onChange(value);
  };

  return /*#__PURE__*/React.createElement(_draftJs.Editor, {
    editorState: editorState,
    onChange: onDraftChange,
    placeholder: placeholder,
    ref: ref
  });
});
HighlightWithinTextarea.propTypes = {
  onChange: _propTypes.default.func,
  value: _propTypes.default.string.isRequired,
  highlight: _propTypes.default.oneOfType([_propTypes.default.string, _propTypes.default.array, _propTypes.default.instanceOf(RegExp)]),
  placeholder: _propTypes.default.string
};
HighlightWithinTextarea.defaultProps = {
  highlight: null,
  placeholder: 'Enter some text...'
};
var _default = HighlightWithinTextarea;
exports.default = _default;